@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.005
+This document describes Attean::API::Binding version 0.006
 
 =head1 DESCRIPTION
 
@@ -71,8 +71,9 @@ otherwise.
 
 use Type::Tiny::Role;
 
-package Attean::API::Binding 0.005 {
+package Attean::API::Binding 0.006 {
 	use Moo::Role;
+	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(zip);
 	use namespace::clean;
 	
@@ -107,6 +108,12 @@ package Attean::API::Binding 0.005 {
 		return scalar(@blanks);
 	}
 	
+	sub is_ground {
+		my $self	= shift;
+		my @bad	= grep { not($_->does('Attean::API::Term')) } $self->values;
+		return (scalar(@bad) == 0);
+	}
+	
 	sub values_consuming_role {
 		my $self	= shift;
 		my $role	= shift;
@@ -116,11 +123,47 @@ package Attean::API::Binding 0.005 {
 	sub tree_attributes {
 		my $self	= shift;
 		return $self->variables;
-	};
+	}
+	
+	sub apply_bindings {
+		my $self	= shift;
+		my $class	= ref($self);
+		my $bind	= shift;
+		my %data;
+		foreach my $k ($self->variables) {
+			my $v	= $self->value($k);
+			if ($v->does('Attean::API::Variable')) {
+				my $name	= $v->value;
+				my $replace	= $bind->value($name);
+				if (defined($replace) and blessed($replace)) {
+					$data{ $k }	= $replace;
+				} else {
+					$data{ $k }	= $v;
+				}
+			} else {
+				$data{ $k }	= $v;
+			}
+		}
+		use Data::Dumper;
+		warn Dumper(\%data);
+		return $class->new( bindings => \%data );
+	}
 }
 
-package Attean::API::TripleOrQuadPattern 0.005 {
+package Attean::API::TripleOrQuadPattern 0.006 {
 	use Moo::Role;
+
+	around BUILDARGS => sub {
+		my $orig 	= shift;
+		my $class	= shift;
+		if (scalar(@_) == 2) {
+			if ($_[0] eq 'bindings') {
+				return $class->$orig(%{ $_[1] });
+			}
+		}
+		return $class->$orig(@_);
+	};
+
 	sub apply_map {
 		my $self	= shift;
 		my $class	= ref($self);
@@ -130,12 +173,12 @@ package Attean::API::TripleOrQuadPattern 0.005 {
 	}
 }
 
-package Attean::API::TripleOrQuad 0.005 {
+package Attean::API::TripleOrQuad 0.006 {
 	use Moo::Role;
 	with 'Attean::API::TripleOrQuadPattern';
 }
 
-package Attean::API::TriplePattern 0.005 {
+package Attean::API::TriplePattern 0.006 {
 	use Moo::Role;
 	use List::MoreUtils qw(zip);
 	use namespace::clean;
@@ -157,9 +200,17 @@ package Attean::API::TriplePattern 0.005 {
 		return Attean::QuadPattern->new(zip @keys, @values);
 	}
 	
+	sub as_triple {
+		my $self	= shift;
+		unless ($self->is_ground) {
+			die "Not a ground triple: " . $self->as_string;
+		}
+		return Attean::Triple->new($self->values);
+	}
+	
 	sub as_sparql {
 		my $self	= shift;
-		return join(' ', map { $_->ntriples_string } $self->values) . " .\n";
+		return join(' ', map { $_->as_sparql } $self->values) . " .\n";
 	}
 	
 	requires 'subject';
@@ -169,7 +220,7 @@ package Attean::API::TriplePattern 0.005 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Triple 0.005 {
+package Attean::API::Triple 0.006 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -204,7 +255,7 @@ package Attean::API::Triple 0.005 {
 	with 'Attean::API::TriplePattern', 'Attean::API::TripleOrQuad', 'Attean::API::Binding';
 }
 
-package Attean::API::QuadPattern 0.005 {
+package Attean::API::QuadPattern 0.006 {
 	use Moo::Role;
 	
 	sub variables { return qw(subject predicate object graph) }
@@ -215,6 +266,14 @@ package Attean::API::QuadPattern 0.005 {
 		die "Unrecognized binding name '$key'";
 	}
 	
+	sub as_quad {
+		my $self	= shift;
+		unless ($self->is_ground) {
+			die "Not a ground quad: " . $self->as_string;
+		}
+		return Attean::Quad->new($self->values);
+	}
+	
 	requires 'subject';
 	requires 'predicate';
 	requires 'object';
@@ -223,7 +282,7 @@ package Attean::API::QuadPattern 0.005 {
 	with 'Attean::API::TripleOrQuadPattern', 'Attean::API::Binding';
 }
 
-package Attean::API::Quad 0.005 {
+package Attean::API::Quad 0.006 {
 	use Moo::Role;
 	
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -250,7 +309,7 @@ package Attean::API::Quad 0.005 {
 }
 
 
-package Attean::API::Result 0.005 {
+package Attean::API::Result 0.006 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use namespace::clean;
