@@ -7,7 +7,7 @@ Attean::Algebra - Representation of SPARQL algebra operators
 
 =head1 VERSION
 
-This document describes Attean::Algebra version 0.005
+This document describes Attean::Algebra version 0.006
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ use Attean::API::Query;
 
 =cut
 
-package Attean::Algebra::Join 0.005 {
+package Attean::Algebra::Join 0.006 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
 	sub algebra_as_string { return 'Join' }
@@ -48,7 +48,7 @@ package Attean::Algebra::Join 0.005 {
 
 =cut
 
-package Attean::Algebra::LeftJoin 0.005 {
+package Attean::Algebra::LeftJoin 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
@@ -66,11 +66,18 @@ package Attean::Algebra::LeftJoin 0.005 {
 		my $indent	= $sp x $level;
 		my ($lhs, $rhs)	= @{ $self->children };
 		
-		return "${indent}{\n"
+		my $s	= "${indent}{\n"
 			. $lhs->as_sparql( %args, level => $level+1 )
 			. "${indent}} OPTIONAL {\n"
-			. $rhs->as_sparql( %args, level => $level+1 )
-			. "${indent}}\n";
+			. $rhs->as_sparql( %args, level => $level+1 );
+		
+		my $e	= $self->expression->as_sparql( %args, level => $level+1 );
+		if ($e ne 'true') {
+			$s	.= "${indent}$e\n";
+		}
+		
+		$s	.= "${indent}}\n";
+		return $s;
 	}
 }
 
@@ -78,7 +85,7 @@ package Attean::Algebra::LeftJoin 0.005 {
 
 =cut
 
-package Attean::Algebra::Filter 0.005 {
+package Attean::Algebra::Filter 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -106,7 +113,7 @@ package Attean::Algebra::Filter 0.005 {
 
 =cut
 
-package Attean::Algebra::Union 0.005 {
+package Attean::Algebra::Union 0.006 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
 	sub algebra_as_string { return 'Union' }
@@ -130,7 +137,7 @@ package Attean::Algebra::Union 0.005 {
 
 =cut
 
-package Attean::Algebra::Graph 0.005 {
+package Attean::Algebra::Graph 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -170,7 +177,7 @@ package Attean::Algebra::Graph 0.005 {
 
 =cut
 
-package Attean::Algebra::Extend 0.005 {
+package Attean::Algebra::Extend 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -224,7 +231,7 @@ package Attean::Algebra::Extend 0.005 {
 
 =cut
 
-package Attean::Algebra::Minus 0.005 {
+package Attean::Algebra::Minus 0.006 {
 	use Moo;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -253,7 +260,7 @@ package Attean::Algebra::Minus 0.005 {
 
 =cut
 
-package Attean::Algebra::Distinct 0.005 {
+package Attean::Algebra::Distinct 0.006 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
 	sub algebra_as_string { return 'Distinct' }
@@ -279,7 +286,7 @@ package Attean::Algebra::Distinct 0.005 {
 
 =cut
 
-package Attean::Algebra::Reduced 0.005 {
+package Attean::Algebra::Reduced 0.006 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
 	sub algebra_as_string { return 'Reduced' }
@@ -305,7 +312,7 @@ package Attean::Algebra::Reduced 0.005 {
 
 =cut
 
-package Attean::Algebra::Slice 0.005 {
+package Attean::Algebra::Slice 0.006 {
 	use Moo;
 	use Types::Standard qw(Int);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -346,7 +353,7 @@ package Attean::Algebra::Slice 0.005 {
 
 =cut
 
-package Attean::Algebra::Project 0.005 {
+package Attean::Algebra::Project 0.006 {
 	use Moo;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -405,7 +412,7 @@ package Attean::Algebra::Project 0.005 {
 
 =cut
 
-package Attean::Algebra::Comparator 0.005 {
+package Attean::Algebra::Comparator 0.006 {
 	use Moo;
 	use Types::Standard qw(Bool ConsumerOf);
 	has 'ascending' => (is => 'ro', isa => Bool, default => 1);
@@ -433,7 +440,7 @@ package Attean::Algebra::Comparator 0.005 {
 
 =cut
 
-package Attean::Algebra::OrderBy 0.005 {
+package Attean::Algebra::OrderBy 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef InstanceOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -462,7 +469,7 @@ package Attean::Algebra::OrderBy 0.005 {
 
 =cut
 
-package Attean::Algebra::BGP 0.005 {
+package Attean::Algebra::BGP 0.006 {
 	use Moo;
 	use Attean::RDF;
 	use Set::Scalar;
@@ -531,7 +538,7 @@ package Attean::Algebra::BGP 0.005 {
 
 =cut
 
-package Attean::Algebra::Service 0.005 {
+package Attean::Algebra::Service 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool);
 	sub algebra_as_string {
@@ -562,7 +569,7 @@ package Attean::Algebra::Service 0.005 {
 
 =cut
 
-package Attean::Algebra::Path 0.005 {
+package Attean::Algebra::Path 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -596,7 +603,7 @@ package Attean::Algebra::Path 0.005 {
 
 =cut
 
-package Attean::Algebra::Group 0.005 {
+package Attean::Algebra::Group 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	sub in_scope_variables {
@@ -662,7 +669,7 @@ package Attean::Algebra::Group 0.005 {
 
 =cut
 
-package Attean::Algebra::NegatedPropertySet 0.005 {
+package Attean::Algebra::NegatedPropertySet 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	with 'Attean::API::PropertyPath';
@@ -683,7 +690,7 @@ package Attean::Algebra::NegatedPropertySet 0.005 {
 
 =cut
 
-package Attean::Algebra::PredicatePath 0.005 {
+package Attean::Algebra::PredicatePath 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::PropertyPath';
@@ -707,7 +714,7 @@ package Attean::Algebra::PredicatePath 0.005 {
 
 =cut
 
-package Attean::Algebra::InversePath 0.005 {
+package Attean::Algebra::InversePath 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -723,7 +730,7 @@ package Attean::Algebra::InversePath 0.005 {
 
 =cut
 
-package Attean::Algebra::SequencePath 0.005 {
+package Attean::Algebra::SequencePath 0.006 {
 	use Moo;
 	with 'Attean::API::NaryPropertyPath';
 	sub separator { return "/" }
@@ -738,7 +745,7 @@ package Attean::Algebra::SequencePath 0.005 {
 
 =cut
 
-package Attean::Algebra::AlternativePath 0.005 {
+package Attean::Algebra::AlternativePath 0.006 {
 	use Moo;
 	with 'Attean::API::NaryPropertyPath';
 	sub separator { return "|" }
@@ -753,7 +760,7 @@ package Attean::Algebra::AlternativePath 0.005 {
 
 =cut
 
-package Attean::Algebra::ZeroOrMorePath 0.005 {
+package Attean::Algebra::ZeroOrMorePath 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -769,7 +776,7 @@ package Attean::Algebra::ZeroOrMorePath 0.005 {
 
 =cut
 
-package Attean::Algebra::OneOrMorePath 0.005 {
+package Attean::Algebra::OneOrMorePath 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -785,7 +792,7 @@ package Attean::Algebra::OneOrMorePath 0.005 {
 
 =cut
 
-package Attean::Algebra::ZeroOrOnePath 0.005 {
+package Attean::Algebra::ZeroOrOnePath 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -801,7 +808,7 @@ package Attean::Algebra::ZeroOrOnePath 0.005 {
 
 =cut
 
-package Attean::Algebra::Table 0.005 {
+package Attean::Algebra::Table 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -834,7 +841,7 @@ package Attean::Algebra::Table 0.005 {
 
 =cut
 
-package Attean::Algebra::Ask 0.005 {
+package Attean::Algebra::Ask 0.006 {
 	use Moo;
 	sub in_scope_variables { return; }
 	with 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -856,7 +863,7 @@ package Attean::Algebra::Ask 0.005 {
 
 =cut
 
-package Attean::Algebra::Construct 0.005 {
+package Attean::Algebra::Construct 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	has 'triples' => (is => 'ro', isa => ArrayRef[ConsumerOf['Attean::API::TriplePattern']]);
