@@ -7,7 +7,7 @@ Attean::Plan - Representation of SPARQL query plan operators
 
 =head1 VERSION
 
-This document describes Attean::Plan version 0.005
+This document describes Attean::Plan version 0.006
 
 =head1 SYNOPSIS
 
@@ -31,7 +31,7 @@ Evaluates a quad pattern against the model.
 
 =cut
 
-package Attean::Plan::Quad 0.005 {
+package Attean::Plan::Quad 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf ArrayRef);
 
@@ -81,7 +81,7 @@ Evaluates a join (natural-, anti-, or left-) using a nested loop.
 
 =cut
 
-package Attean::Plan::NestedLoopJoin 0.005 {
+package Attean::Plan::NestedLoopJoin 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef Str Bool ConsumerOf);
 	with 'Attean::API::Plan', 'Attean::API::BinaryQueryTree';
@@ -144,7 +144,7 @@ Evaluates a join (natural-, anti-, or left-) using a hash join.
 
 =cut
 
-package Attean::Plan::HashJoin 0.005 {
+package Attean::Plan::HashJoin 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef Str ConsumerOf Bool);
 	with 'Attean::API::Plan', 'Attean::API::BinaryQueryTree';
@@ -220,7 +220,7 @@ named variable binding.
 
 =cut
 
-package Attean::Plan::EBVFilter 0.005 {
+package Attean::Plan::EBVFilter 0.006 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ConsumerOf);
@@ -256,7 +256,7 @@ ordering.
 
 =cut
 
-package Attean::Plan::Merge 0.005 {
+package Attean::Plan::Merge 0.006 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ArrayRef ConsumerOf);
@@ -280,7 +280,7 @@ Evaluates a set of sub-plans, returning the union of results.
 
 =cut
 
-package Attean::Plan::Union 0.005 {
+package Attean::Plan::Union 0.006 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	with 'Attean::API::Plan', 'Attean::API::BinaryQueryTree';
@@ -322,10 +322,12 @@ expressions, binding the produced values to new variables.
 
 =cut
 
-package Attean::Plan::Extend 0.005 {
+package Attean::Plan::Extend 0.006 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf HashRef);
+	use namespace::clean;
+
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
 	has 'expressions' => (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::Expression']], required => 1);
 	sub plan_as_string {
@@ -335,6 +337,7 @@ package Attean::Plan::Extend 0.005 {
 	}
 	sub tree_attributes { return qw(variable expression) };
 	
+
 	sub evaluate_expression {
 		my $self	= shift;
 		my $model	= shift;
@@ -373,6 +376,17 @@ package Attean::Plan::Extend 0.005 {
 				my $t		= shift(@terms);
 				my $ok		= (blessed($t) and $t->does($role));
 				return $ok ? $true : $false;
+			} elsif ($func eq 'REGEX') {
+				my ($string, $pattern, $flags)	= map { $self->evaluate_expression($model, $_, $r) } @{ $expr->children };
+				# TODO: ensure that $string is a literal
+				($string, $pattern, $flags)	= map { blessed($_) ? $_->value : '' } ($string, $pattern, $flags);
+				my $re;
+				if ($flags =~ /i/) {
+					$re	= qr/$pattern/i;
+				} else {
+					$re	= qr/$pattern/;
+				}
+				return ($string =~ $re) ? $true : $false;
 			} else {
 				die "Expression evaluation unimplemented: " . $expr->as_string;
 			}
@@ -420,7 +434,7 @@ hash of already-seen results.
 
 =cut
 
-package Attean::Plan::HashDistinct 0.005 {
+package Attean::Plan::HashDistinct 0.006 {
 	use Moo;
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
 	sub plan_as_string { return 'HashDistinct' }
@@ -444,7 +458,7 @@ filtering out sequential duplicates.
 
 =cut
 
-package Attean::Plan::Unique 0.005 {
+package Attean::Plan::Unique 0.006 {
 	use Moo;
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
 	sub plan_as_string { return 'Unique' }
@@ -475,7 +489,7 @@ number of results ("offset") and limiting the total number of returned results
 
 =cut
 
-package Attean::Plan::Slice 0.005 {
+package Attean::Plan::Slice 0.006 {
 	use Moo;
 	use Types::Standard qw(Int);
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
@@ -511,7 +525,7 @@ of variable bindings in each result.
 
 =cut
 
-package Attean::Plan::Project 0.005 {
+package Attean::Plan::Project 0.006 {
 	use Moo;
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -545,7 +559,7 @@ sorting is applied.
 
 =cut
 
-package Attean::Plan::OrderBy 0.005 {
+package Attean::Plan::OrderBy 0.006 {
 	use Moo;
 	use Types::Standard qw(HashRef ArrayRef InstanceOf Bool Str);
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
@@ -595,7 +609,7 @@ Evaluates a SPARQL query against a remove endpoint.
 
 =cut
 
-package Attean::Plan::Service 0.005 {
+package Attean::Plan::Service 0.006 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool Str);
 	sub plan_as_string {
@@ -623,7 +637,7 @@ Returns a constant set of results.
 
 =cut
 
-package Attean::Plan::Table 0.005 {
+package Attean::Plan::Table 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -653,7 +667,7 @@ results were produced by evaluating the sub-plan.
 
 =cut
 
-package Attean::Plan::Exists 0.005 {
+package Attean::Plan::Exists 0.006 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -679,7 +693,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::Ask 0.005 {
+# package Attean::Algebra::Ask 0.006 {
 # 	use Moo;
 # 	sub in_scope_variables { return; }
 # 	with 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -701,7 +715,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::Construct 0.005 {
+# package Attean::Algebra::Construct 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ArrayRef ConsumerOf);
 # 	has 'triples' => (is => 'ro', isa => ArrayRef[ConsumerOf['Attean::API::TriplePattern']]);
@@ -728,7 +742,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::Path 0.005 {
+# package Attean::Algebra::Path 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	sub in_scope_variables {
@@ -766,7 +780,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::NegatedPropertySet 0.005 {
+# package Attean::Algebra::NegatedPropertySet 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ArrayRef ConsumerOf);
 # 	with 'Attean::API::PropertyPath';
@@ -787,7 +801,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::PredicatePath 0.005 {
+# package Attean::Algebra::PredicatePath 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	with 'Attean::API::PropertyPath';
@@ -811,7 +825,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::InversePath 0.005 {
+# package Attean::Algebra::InversePath 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	with 'Attean::API::UnaryPropertyPath';
@@ -827,7 +841,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::SequencePath 0.005 {
+# package Attean::Algebra::SequencePath 0.006 {
 # 	use Moo;
 # 	with 'Attean::API::NaryPropertyPath';
 # 	sub separator { return "/" }
@@ -842,7 +856,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::AlternativePath 0.005 {
+# package Attean::Algebra::AlternativePath 0.006 {
 # 	use Moo;
 # 	with 'Attean::API::NaryPropertyPath';
 # 	sub separator { return "|" }
@@ -857,7 +871,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::ZeroOrMorePath 0.005 {
+# package Attean::Algebra::ZeroOrMorePath 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	with 'Attean::API::UnaryPropertyPath';
@@ -873,7 +887,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::OneOrMorePath 0.005 {
+# package Attean::Algebra::OneOrMorePath 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	with 'Attean::API::UnaryPropertyPath';
@@ -889,7 +903,7 @@ package Attean::Plan::Exists 0.005 {
 # 
 # =cut
 # 
-# package Attean::Algebra::ZeroOrOnePath 0.005 {
+# package Attean::Algebra::ZeroOrOnePath 0.006 {
 # 	use Moo;
 # 	use Types::Standard qw(ConsumerOf);
 # 	with 'Attean::API::UnaryPropertyPath';
